#[non_exhaustive]pub enum BankQuery {
Supply {
denom: String,
},
Balance {
address: String,
denom: String,
},
AllBalances {
address: String,
},
DenomMetadata {
denom: String,
},
AllDenomMetadata {
pagination: Option<PageRequest>,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Supply
This calls into the native bank module for querying the total supply of one denomination. It does the same as the SupplyOf call in Cosmos SDK’s RPC API. Return value is of type SupplyResponse.
Balance
This calls into the native bank module for one denomination Return value is BalanceResponse
AllBalances
Returns a potentially unbound number of results. If you think you have a valid usecase, please open an issue.
This calls into the native bank module for all denominations. Note that this may be much more expensive than Balance and should be avoided if possible. Return value is AllBalanceResponse.
Fields
DenomMetadata
This calls into the native bank module for querying metadata for a specific bank token. Return value is DenomMetadataResponse
AllDenomMetadata
This calls into the native bank module for querying metadata for all bank tokens that have a metadata entry. Return value is AllDenomMetadataResponse
Fields
pagination: Option<PageRequest>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for BankQuery
impl<'de> Deserialize<'de> for BankQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl<C: CustomQuery> From<BankQuery> for QueryRequest<C>
impl<C: CustomQuery> From<BankQuery> for QueryRequest<C>
Sourceimpl JsonSchema for BankQuery
impl JsonSchema for BankQuery
Sourcefn schema_name() -> String
fn schema_name() -> String
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
$ref keyword. Read moreimpl Eq for BankQuery
impl StructuralPartialEq for BankQuery